@@ -79,6 +79,7 @@ if sys.platform.startswith('linux'):
     from pyroute2.netlink.diag import DiagSocket
     from pyroute2.netlink.uevent import UeventSocket
     from pyroute2.netlink.generic import GenericNetlinkSocket
+    from pyroute2.netlink.generic.l2tp import L2tp
     from pyroute2.netlink.generic.wireguard import WireGuard
     from pyroute2.netlink.nfnetlink.nftsocket import NFTSocket
     from pyroute2.netlink.nfnetlink.nfctsocket import NFCTSocket
@@ -156,6 +157,7 @@ if sys.platform.startswith('linux'):
                     DiagSocket,
                     UeventSocket,
                     GenericNetlinkSocket,
+                    L2tp,
                     WireGuard,
                     NFTSocket,
                     NFCTSocket,
