@@ -1,7 +1,4 @@
 '''
-WiSet module
-============
-
 High level ipset support.
 
 When :doc:`ipset` is providing a direct netlink socket with low level
@@ -25,7 +22,7 @@ netlink messages:
 
 >>> wiset.content
 {'1.2.3.0/24': IPStats(packets=None, bytes=None, comment=None,
-                       timeout=None, skbmark=None)}
+                       timeout=None, skbmark=None, physdev=False)}
 '''
 
 import errno
@@ -40,6 +37,8 @@ from pyroute2.netlink.exceptions import IPSetError
 from pyroute2.netlink.nfnetlink.ipset import IPSET_FLAG_WITH_COUNTERS
 from pyroute2.netlink.nfnetlink.ipset import IPSET_FLAG_WITH_COMMENT
 from pyroute2.netlink.nfnetlink.ipset import IPSET_FLAG_WITH_SKBINFO
+from pyroute2.netlink.nfnetlink.ipset import IPSET_FLAG_PHYSDEV
+from pyroute2.netlink.nfnetlink.ipset import IPSET_FLAG_IFACE_WILDCARD
 
 
 # Debug variable to detect netlink socket leaks
@@ -81,8 +80,16 @@ def need_ipset_socket(fun):
     return wrap
 
 
-IPStats = namedtuple("IPStats", ["packets", "bytes", "comment",
-                                 "timeout", "skbmark"])
+class IPStats(namedtuple("IPStats", ["packets", "bytes", "comment",
+                                     "timeout", "skbmark", "physdev",
+                                     "wildcard"])):
+    __slots__ = ()
+
+    def __new__(cls, packets, bytes, comment, timeout, skbmark, physdev=False,
+                wildcard=False):
+        return super(IPStats, cls).__new__(cls, packets, bytes, comment,
+                                           timeout, skbmark, physdev=physdev,
+                                           wildcard=wildcard)
 
 
 # pylint: disable=too-many-instance-attributes
@@ -251,11 +258,20 @@ class WiSet(object):
                     skbmark = "/".join([str(hex(mark)) for mark in skbmark])
                 else:
                     skbmark = str(hex(skbmark[0]))
+            entry_flag_parsed = {"physdev": False}
+            flags = entry.get_attr("IPSET_ATTR_CADT_FLAGS")
+            if flags is not None:
+                entry_flag_parsed["physdev"] = bool(flags &
+                                                    IPSET_FLAG_PHYSDEV)
+                entry_flag_parsed["wildcard"] = bool(flags &
+                                                     IPSET_FLAG_IFACE_WILDCARD)
+
             value = IPStats(packets=entry.get_attr("IPSET_ATTR_PACKETS"),
                             bytes=entry.get_attr("IPSET_ATTR_BYTES"),
                             comment=entry.get_attr("IPSET_ATTR_COMMENT"),
                             skbmark=skbmark,
-                            timeout=timeout)
+                            timeout=timeout,
+                            **entry_flag_parsed)
             self._content[key] = value
 
     def create(self, **kwargs):
@@ -427,7 +443,13 @@ def load_ipset(name, content=False, sock=None, inherit_sock=False):
     :type inherit_sock: bool
     """
     res = None
-    for msg in sock.list(name=name):
+    try:
+        messages = sock.list(name=name)
+    except IPSetError as e:
+        if e.code == errno.ENOENT:
+            return res
+        raise
+    for msg in messages:
         if res is None:
             res = WiSet.from_netlink(msg, content=content)
             if inherit_sock:
